@@ -22,12 +22,3 @@ Rcpp::StringVector rcpp_geojson_dfz( Rcpp::DataFrame df, Rcpp::List geometries )
   return spatialwidget::geojson::to_geojson_z_atomise( df, geometries, -1 );
 }
 
-// [[Rcpp::export]]
-Rcpp::StringVector rcpp_sf_to_geojson_downcast( Rcpp::DataFrame sf, std::string geometry_column ) {
-  return spatialwidget::geojson::to_geojson_downcast_atomise( sf, geometry_column, -1 );
-}
-
-// [[Rcpp::export]]
-Rcpp::StringVector rcpp_sf_to_geojson_multi_column_downcast( Rcpp::DataFrame sf, Rcpp::StringVector geometries ) {
-  return spatialwidget::geojson::to_geojson_downcast_atomise( sf, geometries, -1 );
-}
